package com.ruoyi.quartz.service.impl;

import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.quartz.domain.QuartzDevIotConfigPoint;
import com.ruoyi.quartz.domain.QuartzDevIotDatas;
import com.ruoyi.quartz.domain.QuartzDevIotWarning;
import com.ruoyi.quartz.mapper.QuartzDevIotMapper;
import com.ruoyi.quartz.service.IQuartzDevIotService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.Map;

/**
 * 萨达配电箱数据
 */
@Service
public class QuartzDevIotServiceImpl implements IQuartzDevIotService {

    @Autowired
    private QuartzDevIotMapper devIotMapper;

    /**
     * 获取配电箱配置信息
     */
    @Override
    public List<Map<String, Object>> selectDevIotConfigList() {
        return devIotMapper.selectDevIotConfigList();
    }

    /**
     * 查询配电箱配置列表
     *
     * @param devIotConfigPoint 配电箱配置
     * @return 配电箱配置集合
     */
    @Override
    public List<QuartzDevIotConfigPoint> selectDevIotConfigPointList(QuartzDevIotConfigPoint devIotConfigPoint){
        return devIotMapper.selectDevIotConfigPointList(devIotConfigPoint);
    }

    /**
     * 新增配电箱配置
     *
     * @param devIotConfigPoint 配电箱配置
     * @return 结果
     */
    @Override
    public int insertDevIotConfigPoint(QuartzDevIotConfigPoint devIotConfigPoint)
    {
        devIotConfigPoint.setCreateTime(DateUtils.getNowDate());
        return devIotMapper.insertDevIotConfigPoint(devIotConfigPoint);
    }

    /**
     * 修改配电箱配置
     *
     * @param devIotConfigPoint 配电箱配置
     * @return 结果
     */
    @Override
    public int updateDevIotConfigPoint(QuartzDevIotConfigPoint devIotConfigPoint)
    {
        devIotConfigPoint.setUpdateTime(DateUtils.getNowDate());
        return devIotMapper.updateDevIotConfigPoint(devIotConfigPoint);
    }

    /**
     * 新增配电箱数据
     *
     * @param devIotDatas 配电箱数据
     * @return 结果
     */
    @Override
    public int insertDevIotDatas(QuartzDevIotDatas devIotDatas)
    {
        devIotDatas.setCreateTime(DateUtils.getNowDate());
        return devIotMapper.insertDevIotDatas(devIotDatas);
    }

    /**
     * 新增配电箱预警
     *
     * @param devIotWarning 配电箱预警
     * @return 结果
     */
    @Override
    public int insertDevIotWarning(QuartzDevIotWarning devIotWarning)
    {
        devIotWarning.setCreateTime(DateUtils.getNowDate());
        return devIotMapper.insertDevIotWarning(devIotWarning);
    }

}
