package com.ruoyi.quartz.task;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONArray;
import com.alibaba.fastjson2.JSONObject;
import com.ruoyi.common.constant.ApiConstants;
import com.ruoyi.common.core.text.Convert;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.common.utils.http.HttpUtils;
import com.ruoyi.quartz.domain.QuartzDevIotConfigPoint;
import com.ruoyi.quartz.domain.QuartzDevIotDatas;
import com.ruoyi.quartz.domain.QuartzDevIotWarning;
import com.ruoyi.quartz.service.IQuartzDevIotService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * @Description: 萨达配电箱数据定时任务
 * @Title: SadaHzDataTask
 * @Package com.yanzhu.job.task
 * @Author: JiangYuQi
 * @CreateTime: 2024/10/26 17:05
 */
@Component("sadaHzDataTask")
public class SadaHzDataTask {

    @Autowired
    private IQuartzDevIotService devIotService;

    private static final Logger log = LoggerFactory.getLogger(SadaHzDataTask.class);

    /**
     * 获取配电箱点位
     */
    public void getIotConfigPoint() {
        List<Map<String,Object>> configs = devIotService.selectDevIotConfigList();
        if(configs.size()>0){
            for(Map<String,Object> configMap:configs){
                // 判断是萨达设备
                if(StringUtils.eqObj(configMap.get("factory_name"),"SD")){
                    String signalName = Convert.toStr(configMap.get("signal_name"));
                    String signalCode = Convert.toStr(configMap.get("signal_code"));
                    String projectName = Convert.toStr(configMap.get("project_name"));
                    String projectHashId = getSaDaProjectHashIds(signalName,signalCode,projectName);
                    if(StringUtils.isNotEmpty(projectHashId)){
                        // 根据项目主键，查询设备信息
                        findSaDaBoxByProjectHashId(configMap,projectHashId);
                    }
                }
            }
        }
    }

    /**
     * 获取配电箱数据/预警
     */
    public void getIotPowerDatas() {
        QuartzDevIotConfigPoint pointQuery = new QuartzDevIotConfigPoint();
        pointQuery.setIsDel("0");
        List<QuartzDevIotConfigPoint> configPoints = devIotService.selectDevIotConfigPointList(pointQuery);
        if(configPoints.size()>0){
            for(QuartzDevIotConfigPoint configPoint:configPoints){
                // 判断是萨达设备
                if(StringUtils.eqObj(configPoint.getFactoryName(),"SD")){
                    if(StringUtils.isNotEmpty(configPoint.getDeviceSn())){
                        String resStr = HttpUtils.sendGet(ApiConstants.IOT_SD_HOST + "/metric/box/"+configPoint.getDeviceSn());
                        JSONObject result = JSONObject.parseObject(resStr).getJSONObject("result");
                        // 开关检测数据
                        JSONObject switches = result.getJSONObject("switches");
                        // 电能检测数据
                        JSONObject metric = result.getJSONObject("metric");
                        // 温度检测数据
                        JSONArray temperatures = result.getJSONArray("temperatures");
                        // 漏电检测数据
                        JSONArray leakages = result.getJSONArray("leakages");
                        // 智能报警数据
                        JSONObject ticketStatus = result.getJSONObject("ticketStatus");
                        QuartzDevIotDatas devIotDatas = new QuartzDevIotDatas();
                        devIotDatas.setCfgId(configPoint.getCfgId());
                        devIotDatas.setPointId(configPoint.getId());
                        devIotDatas.setComId(configPoint.getComId());
                        devIotDatas.setProjectId(configPoint.getProjectId());
                        devIotDatas.setDeviceSn(configPoint.getDeviceSn());
                        try {
                            devIotDatas.setSwitchesAc(switches.getString("ac"));
                            devIotDatas.setSwitchesSwitch(switches.getString("switch"));
                            devIotDatas.setSwitchesSwitches(switches.getString("switches"));
                            devIotDatas.setSwitchesSwitchstatus(switches.getString("switchStatus"));
                            devIotDatas.setTemperature(temperatures.getJSONObject(0).getString("temperature"));
                            double leakageValue = 0.00;
                            for (int i = 0; i < leakages.size(); i++) {
                                JSONObject leakage = leakages.getJSONObject(i);
                                if(Convert.toDouble(leakage.get("leakage"),0.00)>leakageValue){
                                    leakageValue = leakage.getDoubleValue("leakage");
                                }
                            }
                            devIotDatas.setLeakage(Convert.toStr(leakageValue));
                            devIotDatas.setVoltageA(metric.getString("voltage_a"));
                            devIotDatas.setVoltageB(metric.getString("voltage_b"));
                            devIotDatas.setVoltageC(metric.getString("voltage_c"));
                            devIotDatas.setVoltageAb(metric.getString("voltage_ab"));
                            devIotDatas.setVoltageBc(metric.getString("voltage_bc"));
                            devIotDatas.setVoltageCa(metric.getString("voltage_ca"));
                            devIotDatas.setCurrentA(metric.getString("current_a"));
                            devIotDatas.setCurrentB(metric.getString("current_b"));
                            devIotDatas.setCurrentC(metric.getString("current_c"));
                            devIotDatas.setPowerA(metric.getString("power_a"));
                            devIotDatas.setPowerB(metric.getString("power_b"));
                            devIotDatas.setPowerC(metric.getString("power_c"));
                            devIotDatas.setEnergyA(metric.getString("energy_a"));
                            devIotDatas.setEnergyB(metric.getString("energy_b"));
                            devIotDatas.setEnergyC(metric.getString("energy_c"));
                            devIotDatas.setFactorA(metric.getString("factor_a"));
                            devIotDatas.setFactorB(metric.getString("factor_b"));
                            devIotDatas.setFactorC(metric.getString("factor_c"));
                            devIotDatas.setFrequencyA(metric.getString("frequency_a"));
                            devIotDatas.setFrequencyB(metric.getString("frequency_b"));
                            devIotDatas.setFrequencyC(metric.getString("frequency_c"));
                            devIotService.insertDevIotDatas(devIotDatas);

                            // 智能预警数据
                            QuartzDevIotWarning devIotWarning = new QuartzDevIotWarning();
                            devIotWarning.setCfgId(configPoint.getCfgId());
                            devIotWarning.setPointId(configPoint.getId());
                            devIotWarning.setComId(configPoint.getComId());
                            devIotWarning.setProjectId(configPoint.getProjectId());
                            devIotWarning.setDeviceSn(devIotDatas.getDeviceSn());
                            if(ticketStatus.getInteger("is_blackout")>0){
                                devIotWarning.setWarningType("断电预警");
                                devIotWarning.setWarningContent("设备触发断电，请排查异常情况");
                                devIotService.insertDevIotWarning(devIotWarning);
                            }
                            if(ticketStatus.getInteger("is_smoke")>0){
                                devIotWarning.setWarningType("烟感报警");
                                devIotWarning.setWarningContent("设备烟感报警，请排查异常情况");
                                devIotService.insertDevIotWarning(devIotWarning);
                            }
                            if(ticketStatus.getInteger("is_overload")>0){
                                devIotWarning.setWarningType("过载报警");
                                devIotWarning.setWarningContent("设备过载报警，请排查异常情况");
                                devIotService.insertDevIotWarning(devIotWarning);
                            }
                            if(ticketStatus.getInteger("is_disconnect")>0){
                                devIotWarning.setWarningType("断开报警");
                                devIotWarning.setWarningContent("设备断开报警，请排查异常情况");
                                devIotService.insertDevIotWarning(devIotWarning);
                            }
                            if(ticketStatus.getInteger("is_overheat")>0){
                                devIotWarning.setWarningType("高温报警");
                                devIotWarning.setWarningContent("设备高温报警，请排查异常情况");
                                devIotService.insertDevIotWarning(devIotWarning);
                            }
                            if(ticketStatus.getInteger("is_leakage")>0){
                                devIotWarning.setWarningType("漏电报警");
                                devIotWarning.setWarningContent("设备漏电报警，请排查异常情况");
                                devIotService.insertDevIotWarning(devIotWarning);
                            }
                        }catch (Exception e){
                            e.printStackTrace();
                        }
                    }
                }
            }
        }
    }

    /**
     * 获取项目配置HashIds
     * @param signalName 通信账号
     * @param signalCode 通信密码
     * @param proName 项目名称
     * @return
     */
    private static String getSaDaProjectHashIds(String signalName, String signalCode, String proName){
        try {
            Map<String, Object> params = new HashMap<>();
            params.put("username",signalName);
            params.put("password",signalCode);
            String resStr = HttpUtils.sendPost(ApiConstants.IOT_SD_HOST+"/v2/api-token-auth", JSON.toJSONString(params));
            JSONObject result = JSONObject.parseObject(resStr).getJSONObject("result");
            JSONObject accountJson = result.getJSONObject("account");
            if(StringUtils.isNotEmpty(accountJson.getString("canViewProjects"))){
                JSONArray canProjects = accountJson.getJSONArray("canViewProjects");
                if(canProjects.size()>0){
                    // 使用 forEach 和 Lambda 遍历
                    for(Object item:canProjects){
                        JSONObject obj = (JSONObject) item;
                        if(StringUtils.eqObj(obj.getString("name"),proName)){
                            return obj.getString("hashId");
                        }
                    }
                    return accountJson.getJSONObject("currentProject").getString("hashId");
                }else{
                    return accountJson.getJSONObject("currentProject").getString("hashId");
                }
            }else{
                return accountJson.getJSONObject("currentProject").getString("hashId");
            }
        }catch (Exception e){
            e.printStackTrace();
        }
        return null;
    }

    /**
     * 获取项目设备
     * @param configMap 配置信息
     * @param proHashId 点位编号
     */
    private void findSaDaBoxByProjectHashId(Map<String,Object> configMap, String proHashId){
        try {
            Long cfgId = Convert.toLong(configMap.get("id"));
            String resStr = HttpUtils.sendGet(ApiConstants.IOT_SD_HOST+"/box/project/"+proHashId);
            JSONArray result = JSONObject.parseObject(resStr).getJSONArray("result");
            if(result.size()>0){
                QuartzDevIotConfigPoint pointQuery = new QuartzDevIotConfigPoint();
                pointQuery.setCfgId(cfgId);
                List<QuartzDevIotConfigPoint> pointList = devIotService.selectDevIotConfigPointList(pointQuery);
                result.forEach(item -> {
                    JSONObject obj = (JSONObject) item;
                    List<QuartzDevIotConfigPoint> pointItems = pointList.stream().filter(point -> StringUtils.eqObj(point.getDeviceSn(),obj.getString("hashId"))).collect(Collectors.toList());
                    if(pointItems.size()>0){
                        QuartzDevIotConfigPoint devIotConfigPoint = pointItems.get(0);
                        devIotConfigPoint.setDeviceName(obj.getString("name"));
                        devIotConfigPoint.setFactoryName(Convert.toStr(configMap.get("factory_name")));
                        devIotConfigPoint.setLevels(obj.getString("level"));
                        devIotConfigPoint.setLeakageCurrent(obj.getString("leakageCurrent"));
                        devIotConfigPoint.setRatedTemperature(obj.getString("ratedTemperature"));
                        devIotConfigPoint.setShortCircuitCurrent(obj.getString("shortCircuitCurrent"));
                        devIotConfigPoint.setRatedCurrent(obj.getString("ratedCurrent"));
                        devIotConfigPoint.setRatedVoltage(obj.getString("ratedVoltage"));
                        devIotConfigPoint.setOnlineStatus(obj.getJSONObject("device").getString("onlineStatus"));
                        devIotService.updateDevIotConfigPoint(devIotConfigPoint);
                    }else{
                        QuartzDevIotConfigPoint devIotConfigPoint = new QuartzDevIotConfigPoint();
                        devIotConfigPoint.setCfgId(cfgId);
                        devIotConfigPoint.setComId(Convert.toLong(configMap.get("com_id")));
                        devIotConfigPoint.setProjectId(Convert.toLong(configMap.get("project_id")));
                        devIotConfigPoint.setDeviceSn(obj.getString("hashId"));
                        devIotConfigPoint.setDeviceName(obj.getString("name"));
                        devIotConfigPoint.setFactoryName(Convert.toStr(configMap.get("factory_name")));
                        devIotConfigPoint.setLevels(obj.getString("level"));
                        devIotConfigPoint.setLeakageCurrent(obj.getString("leakageCurrent"));
                        devIotConfigPoint.setRatedTemperature(obj.getString("ratedTemperature"));
                        devIotConfigPoint.setShortCircuitCurrent(obj.getString("shortCircuitCurrent"));
                        devIotConfigPoint.setRatedCurrent(obj.getString("ratedCurrent"));
                        devIotConfigPoint.setRatedVoltage(obj.getString("ratedVoltage"));
                        devIotConfigPoint.setOnlineStatus(obj.getJSONObject("device").getString("onlineStatus"));
                        devIotService.insertDevIotConfigPoint(devIotConfigPoint);
                    }
                });
            }
        }catch (Exception e){
            e.printStackTrace();
        }
    }

}
