package com.ruoyi.api;

import com.ruoyi.common.annotation.Anonymous;
import com.ruoyi.common.annotation.RateLimiter;
import com.ruoyi.common.constant.CacheConstants;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.redis.RedisCache;
import com.ruoyi.common.core.text.Convert;
import com.ruoyi.common.enums.HttpStatusEnum;
import com.ruoyi.common.enums.LimitType;
import com.ruoyi.common.exception.ServiceException;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.domain.TowerReqVo;
import com.ruoyi.domain.vo.TyTowerRoundReqVO;
import com.ruoyi.domain.vo.TyTowerRunReqVO;
import com.ruoyi.domain.vo.TyTowerWarningReqVO;
import com.ruoyi.emuns.TowerTypeEnums;
import com.yanzhu.jh.device.domain.*;
import com.yanzhu.jh.device.service.*;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.validation.Valid;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 塔吊监测APIController
 *
 * @author JiangYuQi
 * @date 2024-01-13
 */
@Slf4j
@RestController
@RequestMapping("/desApi/towerCrane")
public class TowerCraneApiController {

    @Autowired
    private RedisCache redisCache;

    @Autowired
    private IDevTowerDataRunService devTowerDataRunService;

    @Autowired
    private IDevTowerDataRoundService devTowerDataRoundService;

    @Autowired
    private IDevTowerDataLimitService devTowerDataLimitService;

    @Autowired
    private IDevTowerDataLocalService devTowerDataLocalService;

    @Autowired
    private IDevTowerDataCollideService devTowerDataCollideService;

    @Autowired
    private IDevTowerDataWarningService devTowerDataWarningService;

    @Autowired
    private IDevTowerProjectConfigService devTowerProjectConfigService;

    private String YANZHU_DEVICE_TOWER = "device.tower_cfg:";

    /**
     * 塔机限位数据
     */
    private Map<String, DevTowerDataLimit> staticLimitMap = new HashMap<>();

    /**
     * 塔吊监测++
     * 限流规则[60秒内最多请求10次，限流策略IP]
     * @param req 请求信息
     * @author JiangYuQi
     * @date 2024-01-13
     */
    @Anonymous
    @ApiOperation(value = "塔吊监测")
    @RateLimiter(count = 10, limitType = LimitType.IP)
    @PostMapping("/v1/push")
    public AjaxResult pushData(@Validated @RequestBody TowerReqVo req) {
        DevTowerProjectConfig config = redisCache.getCacheObject(CacheConstants.YANZHU_DEVICE_TOWER+req.getContent().getDeviceKey());
        if(config==null){
            throw new ServiceException(HttpStatusEnum.DARA_EXCEPTION.getInfo(),HttpStatusEnum.DARA_EXCEPTION.getCode());
        }
        if(req.getType() == TowerTypeEnums.BASE.getCode()){
            this.pushConfigData(config,req);
        }else if(req.getType() == TowerTypeEnums.RUN.getCode()){
            this.pushRunData(config,req);
        }else if(req.getType() == TowerTypeEnums.ROUND.getCode()){
            this.pushRoundData(config,req);
        }else if(req.getType() == TowerTypeEnums.COLLIDE.getCode()){
            this.pushCollideData(config,req);
        }else if(req.getType() == TowerTypeEnums.LIMIT.getCode()){
            this.pushLimitData(config,req);
        }else if(req.getType() == TowerTypeEnums.LOCAL.getCode()){
            this.pushLocalData(config,req);
        }
        return AjaxResult.success();
    }

    /**
     * 塔机上报基本信息
     * @param req
     */
    private void pushConfigData(DevTowerProjectConfig config,TowerReqVo req){
        DevTowerProjectConfig devTowerProjectConfig = devTowerProjectConfigService.selectDevTowerProjectConfigById(config.getId());
        Map<String, Object> dataContent = req.getContent().getDataContent();
        devTowerProjectConfig.setTowerId(Convert.toStr(dataContent.get("towerId")));
        devTowerProjectConfig.setTowerType(Convert.toStr(dataContent.get("towerType")));
        devTowerProjectConfig.setCoordinateX(Convert.toStr(dataContent.get("coordinateX")));
        devTowerProjectConfig.setCoordinateY(Convert.toStr(dataContent.get("coordinateY")));
        devTowerProjectConfig.setFrontBrachium(Convert.toStr(dataContent.get("frontBrachium")));
        devTowerProjectConfig.setAfterBrachium(Convert.toStr(dataContent.get("afterBrachium")));
        devTowerProjectConfig.setTowerBodyHeight(Convert.toStr(dataContent.get("towerBodyHeight")));
        devTowerProjectConfig.setTowerCapHeight(Convert.toStr(dataContent.get("towerCapHeight")));
        devTowerProjectConfig.setTowerSectionHeight(Convert.toStr(dataContent.get("towerSectionHeight")));
        devTowerProjectConfigService.updateDevTowerProjectConfigNoCache(devTowerProjectConfig);
    }

    /**
     * 塔机上报实时数据
     * @param req
     */
    private void pushRunData(DevTowerProjectConfig config,TowerReqVo req){
        DevTowerDataRun devTowerDataRun = new DevTowerDataRun();
        Map<String, Object> dataContent = req.getContent().getDataContent();
        devTowerDataRun.setCfgId(config.getId());
        devTowerDataRun.setProjectId(config.getProjectId());
        devTowerDataRun.setDeptId(config.getDeptId());
        devTowerDataRun.setDeviceKey(config.getDeviceSn());
        devTowerDataRun.setHeight(Convert.toStr(dataContent.get("height")));
        devTowerDataRun.setRange(Convert.toStr(dataContent.get("range")));
        devTowerDataRun.setRotation(Convert.toStr(dataContent.get("rotation")));
        devTowerDataRun.setLoad(Convert.toStr(dataContent.get("load")));
        devTowerDataRun.setWindSpeed(Convert.toStr(dataContent.get("windSpeed")));
        devTowerDataRun.setLeanAngleX(Convert.toStr(dataContent.get("leanAngleX")));
        devTowerDataRun.setLeanAngleY(Convert.toStr(dataContent.get("leanAngleY")));
        devTowerDataRun.setLoadPercent(Convert.toStr(dataContent.get("loadPercent")));
        devTowerDataRun.setMomentPercent(Convert.toStr(dataContent.get("momentPercent")));
        devTowerDataRun.setWindSpeedPercent(Convert.toStr(dataContent.get("windSpeedPercent")));
        devTowerDataRun.setLeanAnglePercent(Convert.toStr(dataContent.get("leanAnglePercent")));
        devTowerDataRun.setRate(Convert.toStr(dataContent.get("rate")));
        devTowerDataRun.setRotationSensorState(Convert.toStr(dataContent.get("rotationSensorState")));
        devTowerDataRun.setLoadSensorState(Convert.toStr(dataContent.get("loadSensorState")));
        devTowerDataRun.setWindSpeedSensorState(Convert.toStr(dataContent.get("windSpeedSensorState")));
        devTowerDataRun.setLeanAngleSensorState(Convert.toStr(dataContent.get("leanAngleSensorState")));
        devTowerDataRun.setRangeSensorState(Convert.toStr(dataContent.get("rangeSensorState")));
        devTowerDataRun.setHeightSensorState(Convert.toStr(dataContent.get("heightSensorState")));
        devTowerDataRun.setBrakingStatus(Convert.toStr(dataContent.get("brakingStatus")));
        if (dataContent.get("warnings") != null) {
            List<String> warnings = (List<String>) dataContent.get("warnings");
            devTowerDataRun.setWarnings(String.join(",", warnings));
            for (String warning : warnings) {
                pushWarningData(config, warning, devTowerDataRun);
                Integer alarm = Convert.toInt(warning);
                if (alarm > 100 && alarm < 120) {
                    devTowerDataRun.setIsAlarm(1L);
                }
            }
        }
        devTowerDataRunService.insertDevTowerDataRun(devTowerDataRun);
    }

    /**
     * 塔机上报循环数据
     * @param req
     */
    private void pushRoundData(DevTowerProjectConfig config,TowerReqVo req){
        DevTowerDataRound devTowerDataRound = new DevTowerDataRound();
        Map<String, Object> dataContent = req.getContent().getDataContent();
        devTowerDataRound.setCfgId(config.getId());
        devTowerDataRound.setProjectId(config.getProjectId());
        devTowerDataRound.setDeptId(config.getDeptId());
        devTowerDataRound.setDeviceKey(config.getDeviceSn());
        devTowerDataRound.setTowerId(Convert.toStr(dataContent.get("towerId")));
        devTowerDataRound.setWorkStartTime(Convert.toStr(dataContent.get("workStartTime")));
        devTowerDataRound.setWorkEndTime(Convert.toStr(dataContent.get("workEndTime")));
        devTowerDataRound.setMinHeight(Convert.toStr(dataContent.get("minHeight")));
        devTowerDataRound.setMaxHeight(Convert.toStr(dataContent.get("maxHeight")));
        devTowerDataRound.setMinRange(Convert.toStr(dataContent.get("minRange")));
        devTowerDataRound.setMaxRange(Convert.toStr(dataContent.get("maxRange")));
        devTowerDataRound.setStartHeight(Convert.toStr(dataContent.get("startHeight")));
        devTowerDataRound.setEndHeight(Convert.toStr(dataContent.get("endHeight")));
        devTowerDataRound.setStartRange(Convert.toStr(dataContent.get("startRange")));
        devTowerDataRound.setEndRange(Convert.toStr(dataContent.get("endRange")));
        devTowerDataRound.setStartRotation(Convert.toStr(dataContent.get("startRotation")));
        devTowerDataRound.setEndRotation(Convert.toStr(dataContent.get("endRotation")));
        devTowerDataRound.setMaxLoad(Convert.toStr(dataContent.get("maxLoad")));
        devTowerDataRound.setMaxLoadPercent(Convert.toStr(dataContent.get("maxLoadPercent")));
        devTowerDataRound.setMaxMoment(Convert.toStr(dataContent.get("maxMoment")));
        devTowerDataRound.setMaxMomentPercent(Convert.toStr(dataContent.get("maxMomentPercent")));
        devTowerDataRound.setStartWindSpeed(Convert.toStr(dataContent.get("startWindSpeed")));
        devTowerDataRound.setEndWindSpeed(Convert.toStr(dataContent.get("endWindSpeed")));
        devTowerDataRound.setStartWindSpeedPercent(Convert.toStr(dataContent.get("startWindSpeedPercent")));
        devTowerDataRound.setEndWindSpeedPercent(Convert.toStr(dataContent.get("endWindSpeedPercent")));
        devTowerDataRound.setStartLeanAngleX(Convert.toStr(dataContent.get("startleanAngleX")));
        devTowerDataRound.setEndLeanAngleX(Convert.toStr(dataContent.get("endLeanAngleX")));
        devTowerDataRound.setStartLeanAngleY(Convert.toStr(dataContent.get("startleanAngleY")));
        devTowerDataRound.setEndLeanAngleY(Convert.toStr(dataContent.get("endLeanAngleY")));
        if (dataContent.get("warning") != null) {
            List<String> warnings = (List<String>) dataContent.get("warning");
            devTowerDataRound.setWarnings(String.join(",", warnings));
            for (String warning : warnings) {
                pushWarningData(config, warning,null);
                Integer alarm = Convert.toInt(warning);
                if (alarm > 6 && alarm < 10) {
                    devTowerDataRound.setIsOverload(1L);
                }
                if (alarm > 100 && alarm < 120) {
                    devTowerDataRound.setIsAlarm(1L);
                }
            }
        }
        devTowerDataRoundService.insertDevTowerDataRound(devTowerDataRound);
    }

    /**
     * 保存预警数据
     *
     * @param config
     * @param warning
     */
    private void pushWarningData(DevTowerProjectConfig config, Object warning, DevTowerDataRun devTowerDataRun) {
        DevTowerDataWarning devTowerDataWarning = new DevTowerDataWarning();
        devTowerDataWarning.setCfgId(config.getId());
        devTowerDataWarning.setProjectId(config.getProjectId());
        devTowerDataWarning.setDeviceKey(config.getDeviceSn());
        devTowerDataWarning.setWarnType(Convert.toLong(warning));
        if(devTowerDataRun!=null){
            devTowerDataWarning.setHeight(devTowerDataRun.getHeight());
            devTowerDataWarning.setRange(devTowerDataRun.getRange());
            devTowerDataWarning.setRotation(devTowerDataRun.getRotation());
            devTowerDataWarning.setLoad(devTowerDataRun.getLoad());
            devTowerDataWarning.setWindSpeed(devTowerDataRun.getWindSpeed());
            devTowerDataWarning.setLeanAngleX(devTowerDataRun.getLeanAngleX());
            devTowerDataWarning.setLeanAngleY(devTowerDataRun.getLeanAngleY());
            devTowerDataWarning.setMomentPercent(devTowerDataRun.getMomentPercent());
            devTowerDataWarning.setRate(devTowerDataRun.getRate());
        }
        if(devTowerDataWarning.getWarnType()>100){
            devTowerDataWarning.setAlarmed(1L);
        }
        devTowerDataWarningService.insertDevTowerDataWarning(devTowerDataWarning);
    }

    /**
     * 塔机上报碰撞信息
     * @param req
     */
    private void pushCollideData(DevTowerProjectConfig config,TowerReqVo req){
        DevTowerDataCollide devTowerDataCollide = new DevTowerDataCollide();
        Map<String, Object> dataContent = req.getContent().getLocalDeviceInfo();
        devTowerDataCollide.setCfgId(config.getId());
        devTowerDataCollide.setProjectId(config.getProjectId());
        devTowerDataCollide.setDeptId(config.getDeptId());
        devTowerDataCollide.setDeviceKey(config.getDeviceSn());
        devTowerDataCollide.setTowerId(Convert.toStr(dataContent.get("towerId")));
        devTowerDataCollide.setCoordinateX(Convert.toStr(dataContent.get("coordinateX")));
        devTowerDataCollide.setCoordinateY(Convert.toStr(dataContent.get("coordinateY")));
        devTowerDataCollide.setFrontBrachium(Convert.toStr(dataContent.get("frontBrachium")));
        devTowerDataCollide.setAfterBrachium(Convert.toStr(dataContent.get("afterBrachium")));
        devTowerDataCollide.setTowerBodyHeight(Convert.toStr(dataContent.get("towerBodyHeight")));
        devTowerDataCollide.setHeight(Convert.toStr(dataContent.get("height")));
        devTowerDataCollide.setAngle(Convert.toStr(dataContent.get("angle")));
        devTowerDataCollide.setRange(Convert.toStr(dataContent.get("range")));
        devTowerDataCollide.setEarlyWarningDistance(Convert.toStr(dataContent.get("earlyWarningDistance")));
        devTowerDataCollide.setAlarmWarningDistance(Convert.toStr(dataContent.get("alarmWarningDistance")));
        devTowerDataCollide.setContourValue(Convert.toStr(dataContent.get("contourValue")));
        List<DevTowerDataCollideDetail> devTowerDataCollideDetailList = new ArrayList<>();
        if(StringUtils.isNotEmpty(req.getContent().getCollideTowers())){
            for (Map<String, Object> collideTowers:req.getContent().getCollideTowers()){
                DevTowerDataCollideDetail devTowerDataCollideDetail = new DevTowerDataCollideDetail();
                devTowerDataCollideDetail.setTowerId(Convert.toStr(collideTowers.get("towerId")));
                devTowerDataCollideDetail.setCoordinateX(Convert.toStr(collideTowers.get("coordinateX")));
                devTowerDataCollideDetail.setCoordinateY(Convert.toStr(collideTowers.get("coordinateY")));
                devTowerDataCollideDetail.setFrontBrachium(Convert.toStr(collideTowers.get("frontBrachium")));
                devTowerDataCollideDetail.setAfterBrachium(Convert.toStr(collideTowers.get("afterBrachium")));
                devTowerDataCollideDetail.setTowerBodyHeight(Convert.toStr(collideTowers.get("towerBodyHeight")));
                devTowerDataCollideDetail.setHeight(Convert.toStr(collideTowers.get("height")));
                devTowerDataCollideDetail.setAngle(Convert.toStr(collideTowers.get("angle")));
                devTowerDataCollideDetail.setRange(Convert.toStr(collideTowers.get("range")));
                devTowerDataCollideDetail.setCollideHorizontalDistance(Convert.toStr(collideTowers.get("collideHorizontalDistance")));
                devTowerDataCollideDetail.setCollideVerticalDistance(Convert.toStr(collideTowers.get("collideVerticalDistance")));
                devTowerDataCollideDetail.setCollideState(Convert.toStr(collideTowers.get("collideState")));
                devTowerDataCollideDetailList.add(devTowerDataCollideDetail);
            }
            devTowerDataCollide.setDevTowerDataCollideDetailList(devTowerDataCollideDetailList);
        }
        devTowerDataCollideService.insertDevTowerDataCollide(devTowerDataCollide);
    }

    /**
     * 塔机上报限位信息
     * @param req
     */
    private void pushLimitData(DevTowerProjectConfig config,TowerReqVo req){
        DevTowerDataLimit devTowerDataLimit = new DevTowerDataLimit();
        Map<String, Object> dataContent = req.getContent().getDataContent();
        devTowerDataLimit.setCfgId(config.getId());
        devTowerDataLimit.setProjectId(config.getProjectId());
        devTowerDataLimit.setDeptId(config.getDeptId());
        devTowerDataLimit.setDeviceKey(config.getDeviceSn());
        devTowerDataLimit.setTowerId(Convert.toStr(dataContent.get("towerId")));
        devTowerDataLimit.setWindSpeedWarning(Convert.toStr(dataContent.get("windSpeedWarning")));
        devTowerDataLimit.setWindSpeedAlarm(Convert.toStr(dataContent.get("windSpeedAlarm")));
        devTowerDataLimit.setLoadWarning(Convert.toStr(dataContent.get("loadWarning")));
        devTowerDataLimit.setLoadAlarm(Convert.toStr(dataContent.get("loadAlarm")));
        devTowerDataLimit.setMomentWarning(Convert.toStr(dataContent.get("momentWarning")));
        devTowerDataLimit.setMomentAlarm(Convert.toStr(dataContent.get("momentAlarm")));
        devTowerDataLimit.setHighLimitWarning(Convert.toStr(dataContent.get("highLimitWarning")));
        devTowerDataLimit.setHighLimitAlarm(Convert.toStr(dataContent.get("highLimitAlarm")));
        devTowerDataLimit.setLowLimitWarning(Convert.toStr(dataContent.get("lowLimitWarning")));
        devTowerDataLimit.setLowLimitAlarm(Convert.toStr(dataContent.get("lowLimitAlarm")));
        devTowerDataLimit.setLeftLimitWarning(Convert.toStr(dataContent.get("leftLimitWarning")));
        devTowerDataLimit.setLeftLimitAlarm(Convert.toStr(dataContent.get("leftLimitAlarm")));
        devTowerDataLimit.setRightLimitWarning(Convert.toStr(dataContent.get("rightLimitWarning")));
        devTowerDataLimit.setRightLimitAlarm(Convert.toStr(dataContent.get("rightLimitAlarm")));
        devTowerDataLimit.setFrontLimitWarning(Convert.toStr(dataContent.get("frontLimitWarning")));
        devTowerDataLimit.setFrontLimitAlarm(Convert.toStr(dataContent.get("frontLimitAlarm")));
        devTowerDataLimit.setBackLimitWarning(Convert.toStr(dataContent.get("backLimitWarning")));
        devTowerDataLimit.setBackLimitAlarm(Convert.toStr(dataContent.get("backLimitAlarm")));
        devTowerDataLimit.setCollisionAngleWarning(Convert.toStr(dataContent.get("collisionAngleWarning")));
        devTowerDataLimit.setCollisionAngleAlarm(Convert.toStr(dataContent.get("collisionAngleAlarm")));
        devTowerDataLimit.setCollisionDistanceWarning(Convert.toStr(dataContent.get("collisionDistanceWarning")));
        devTowerDataLimit.setCollisionDistanceAlarm(Convert.toStr(dataContent.get("collisionDistanceAlarm")));
        devTowerDataLimit.sethDistanceWarning(Convert.toStr(dataContent.get("hDistanceWarning")));
        devTowerDataLimit.sethDistanceAlarm(Convert.toStr(dataContent.get("hDistanceAlarm")));
        devTowerDataLimit.setvDistanceWarning(Convert.toStr(dataContent.get("vDistanceWarning")));
        devTowerDataLimit.setvDistanceAlarm(Convert.toStr(dataContent.get("vDistanceAlarm")));
        devTowerDataLimit.setLeanWarning(Convert.toStr(dataContent.get("leanWarning")));
        devTowerDataLimit.setLeanAlarm(Convert.toStr(dataContent.get("leanAlarm")));
        devTowerDataLimit.setRangeLimitStart(Convert.toStr(dataContent.get("rangeLimitStart")));
        devTowerDataLimit.setRangeLimitEnd(Convert.toStr(dataContent.get("rangeLimitEnd")));
        devTowerDataLimit.setHeightLimitStart(Convert.toStr(dataContent.get("heightLimitStart")));
        devTowerDataLimit.setHeightLimitEnd(Convert.toStr(dataContent.get("heightLimitEnd")));
        devTowerDataLimit.setRotationLimitStart(Convert.toStr(dataContent.get("rotationLimitStart")));
        devTowerDataLimit.setRotationLimitEnd(Convert.toStr(dataContent.get("rotationLimitEnd")));
        devTowerDataLimitService.insertDevTowerDataLimit(devTowerDataLimit);
    }

    /**
     * 塔机上报标定位信息
     * @param req
     */
    private void pushLocalData(DevTowerProjectConfig config,TowerReqVo req){
        DevTowerDataLocal devTowerDataLocal = new DevTowerDataLocal();
        Map<String, Object> dataContent = req.getContent().getDataContent();
        devTowerDataLocal.setCfgId(config.getId());
        devTowerDataLocal.setProjectId(config.getProjectId());
        devTowerDataLocal.setDeptId(config.getDeptId());
        devTowerDataLocal.setDeviceKey(config.getDeviceSn());
        devTowerDataLocal.setTowerId(Convert.toStr(dataContent.get("towerId")));
        devTowerDataLocal.setRangeNearEndAdValue(Convert.toStr(dataContent.get("rangeNearEndADValue")));
        devTowerDataLocal.setRangeNearEndRealityValue(Convert.toStr(dataContent.get("rangeNearEndRealityValue")));
        devTowerDataLocal.setRangeFarEndAdValue(Convert.toStr(dataContent.get("rangeFarEndADValue")));
        devTowerDataLocal.setRangeFarEndRealityValue(Convert.toStr(dataContent.get("rangeFarEndRealityValue")));
        devTowerDataLocal.setHighNearEndAdValue(Convert.toStr(dataContent.get("highNearEndADValue")));
        devTowerDataLocal.setHighNearEndRealityValue(Convert.toStr(dataContent.get("highNearEndRealityValue")));
        devTowerDataLocal.setHighFarEndAdValue(Convert.toStr(dataContent.get("highFarEndADValue")));
        devTowerDataLocal.setHighFarEndRealityValue(Convert.toStr(dataContent.get("highFarEndRealityValue")));
        devTowerDataLocal.setEmptyWeightAdValue(Convert.toStr(dataContent.get("emptyWeightADValue")));
        devTowerDataLocal.setEmptyWeightRealityValue(Convert.toStr(dataContent.get("emptyWeightRealityValue")));
        devTowerDataLocal.setLoadWeightAdValue(Convert.toStr(dataContent.get("loadWeightADValue")));
        devTowerDataLocal.setLoadWeightRealityValue(Convert.toStr(dataContent.get("loadWeightRealityValue")));
        devTowerDataLocal.setRotationStartAdValue(Convert.toStr(dataContent.get("rotationStartADValue")));
        devTowerDataLocal.setRotationStartRealityValue(Convert.toStr(dataContent.get("rotationStartRealityValue")));
        devTowerDataLocal.setRotationEndAdValue(Convert.toStr(dataContent.get("rotationEndADValue")));
        devTowerDataLocal.setRotationEndRealityValue(Convert.toStr(dataContent.get("rotationEndRealityValue")));
        devTowerDataLocal.setWindSpeedFactor(Convert.toStr(dataContent.get("windSpeedFactor")));
        devTowerDataLocal.setTiltFactor(Convert.toStr(dataContent.get("tiltFactor")));
        devTowerDataLocalService.insertDevTowerDataLocal(devTowerDataLocal);
    }

    /**
     * 塔吊监测++
     * 限流规则[60秒内最多请求10次，限流策略IP]
     *
     * @param req 请求信息
     * @author JiangYuQi
     * @date 2024-01-13
     */
    @Anonymous
    @ApiOperation(value = "山东探越-塔吊监测-实时数据")
    @RateLimiter(count = 10, limitType = LimitType.IP)
    @PostMapping("/v2_ty/run/push")
    public AjaxResult tyPushRunData(@RequestBody @Valid TyTowerRunReqVO req) {
        log.info("desApi.towerCrane.v2_ty.run.push...{}",req.getEid());
        DevTowerProjectConfig config = redisCache.getCacheObject(YANZHU_DEVICE_TOWER + req.getEid());
        if (config == null) {
            throw new ServiceException(HttpStatusEnum.ERROR.getInfo()+"::"+req.getEid(), HttpStatusEnum.ERROR.getCode());
        }
        String deviceKey = req.getEid().toString();
        DevTowerDataLimit devTowerDataLimit = staticLimitMap.get(deviceKey);
        if(devTowerDataLimit==null){
            DevTowerDataLimit devTowerDataLimitQuery = new DevTowerDataLimit();
            devTowerDataLimitQuery.setDeviceKey(deviceKey);
            devTowerDataLimitQuery.setProjectId(config.getProjectId());
            List<DevTowerDataLimit> limitList = devTowerDataLimitService.selectDevTowerDataLimitList(devTowerDataLimitQuery);
            if(limitList.size()>0){
                devTowerDataLimit = limitList.get(0);
                staticLimitMap.put(deviceKey,devTowerDataLimit);
            }else{
                devTowerDataLimit = new DevTowerDataLimit();
            }
        }

        DevTowerDataRun devTowerDataRun = new DevTowerDataRun();
        devTowerDataRun.setCfgId(config.getId());
        devTowerDataRun.setProjectId(config.getProjectId());
        devTowerDataRun.setDeviceKey(config.getDeviceSn());
        devTowerDataRun.setHeight(Convert.toStr(req.getHeight()));
        devTowerDataRun.setRange(Convert.toStr(req.getRange()));
        devTowerDataRun.setRotation(Convert.toStr(req.getRotation_angle()));
        devTowerDataRun.setLoad(String.format("%.2f", req.getLifting_weight()/1000));
        Double limitLoad = Convert.toDouble(devTowerDataLimit.getLoadAlarm(),50.0);
        devTowerDataRun.setLoadPercent(String.format("%.2f", (req.getLifting_weight()/10)/limitLoad));
        devTowerDataRun.setWindSpeed(Convert.toStr(req.getWind_speed()));
        devTowerDataRun.setLeanAngleX(Convert.toStr(req.getAnteversion_x()));
        devTowerDataRun.setLeanAngleY(Convert.toStr(req.getAnteversion_y()));
        devTowerDataRun.setMomentPercent(Convert.toStr(req.getForce_distance()));
        devTowerDataRun.setRate(Convert.toStr(req.getMagnification()));
        devTowerDataRunService.insertDevTowerDataRun(devTowerDataRun);
        return AjaxResult.success();
    }

    /**
     * 塔吊监测++
     * 限流规则[60秒内最多请求10次，限流策略IP]
     *
     * @param req 请求信息
     * @author JiangYuQi
     * @date 2024-01-13
     */
    @Anonymous
    @ApiOperation(value = "山东探越-塔吊监测-循环数据")
    @RateLimiter(count = 10, limitType = LimitType.IP)
    @PostMapping("/v2_ty/round/push")
    public AjaxResult tyPushRoundData(@RequestBody @Valid TyTowerRoundReqVO req) {
        log.info("desApi.towerCrane.v2_ty.round.push...{}",req.getEid());
        DevTowerProjectConfig config = redisCache.getCacheObject(YANZHU_DEVICE_TOWER + req.getEid());
        if (config == null) {
            throw new ServiceException(HttpStatusEnum.ERROR.getInfo()+"::"+req.getEid(), HttpStatusEnum.ERROR.getCode());
        }
        DevTowerDataRound devTowerDataRound = new DevTowerDataRound();
        devTowerDataRound.setCfgId(config.getId());
        devTowerDataRound.setProjectId(config.getProjectId());
        devTowerDataRound.setDeviceKey(config.getDeviceSn());
        devTowerDataRound.setWorkStartTime(Convert.toStr(req.getStart_time()));
        devTowerDataRound.setWorkEndTime(Convert.toStr(req.getEnd_time()));
        devTowerDataRound.setMinHeight(Convert.toStr(req.getStart_height()));
        devTowerDataRound.setMaxHeight(Convert.toStr(req.getEnd_height()));
        devTowerDataRound.setMinRange(Convert.toStr(req.getStart_range()));
        devTowerDataRound.setMaxRange(Convert.toStr(req.getEnd_range()));
        devTowerDataRound.setStartHeight(Convert.toStr(req.getStart_height()));
        devTowerDataRound.setEndHeight(Convert.toStr(req.getEnd_height()));
        devTowerDataRound.setStartRange(Convert.toStr(req.getStart_range()));
        devTowerDataRound.setEndRange(Convert.toStr(req.getEnd_range()));
        devTowerDataRound.setStartRotation(Convert.toStr(req.getStart_rotation_angle()));
        devTowerDataRound.setEndRotation(Convert.toStr(req.getEnd_rotation_angle()));
        devTowerDataRound.setMaxLoad(String.format("%.2f", req.getWeight()/1000));
        devTowerDataRound.setMaxMomentPercent(Convert.toStr(req.getMoment_percent()));
        devTowerDataRoundService.insertDevTowerDataRound(devTowerDataRound);
        return AjaxResult.success();
    }

    /**
     * 塔吊监测++
     * 限流规则[60秒内最多请求10次，限流策略IP]
     *
     * @param req 请求信息
     * @author JiangYuQi
     * @date 2024-01-13
     */
    @Anonymous
    @ApiOperation(value = "山东探越-塔吊监测-预警数据")
    @RateLimiter(count = 10, limitType = LimitType.IP)
    @PostMapping("/v2_ty/warning/push")
    public AjaxResult tyPushWarningData(@RequestBody @Valid TyTowerWarningReqVO req) {
        log.info("desApi.towerCrane.v2_ty.warning.push...{}",req.getEid());
        DevTowerProjectConfig config = redisCache.getCacheObject(YANZHU_DEVICE_TOWER + req.getEid());
        if (config == null) {
            throw new ServiceException(HttpStatusEnum.ERROR.getInfo()+"::"+req.getEid(), HttpStatusEnum.ERROR.getCode());
        }
        DevTowerDataWarning devTowerDataWarning = new DevTowerDataWarning();
        devTowerDataWarning.setCfgId(config.getId());
        devTowerDataWarning.setProjectId(config.getProjectId());
        devTowerDataWarning.setDeviceKey(config.getDeviceSn());
        String warningType = convertTyTowerWarningType(req.getType_id().toString());
        devTowerDataWarning.setWarnType(Convert.toLong(warningType));
        devTowerDataWarning.setWarnNote(req.getType());
        devTowerDataWarning.setHeight(Convert.toStr(req.getHeight()));
        devTowerDataWarning.setRange(Convert.toStr(req.getRange()));
        devTowerDataWarning.setRotation(Convert.toStr(req.getRotation()));
        devTowerDataWarning.setLoad(String.format("%.2f", req.getLifting_weight()/1000));
        devTowerDataWarning.setWindSpeed(Convert.toStr(req.getWind_speed()));
        devTowerDataWarning.setLeanAngleX(Convert.toStr(req.getAnteversion_x()));
        devTowerDataWarning.setLeanAngleY(Convert.toStr(req.getAnteversion_y()));
        devTowerDataWarning.setMomentPercent(Convert.toStr(req.getForce_distance()));
        devTowerDataWarning.setRate(Convert.toStr(req.getMagnification()));
        if(devTowerDataWarning.getWarnType()>100){
            devTowerDataWarning.setAlarmed(1L);
        }
        devTowerDataWarningService.insertDevTowerDataWarning(devTowerDataWarning);
        return AjaxResult.success();
    }

    /**
     * 转换预警类型
     *
     * @param warningType
     * @return
     */
    private String convertTyTowerWarningType(String warningType) {
        String warningTypeEs;
        switch (warningType) {
            case "1":
                warningTypeEs = "5";
                break;
            case "2":
                warningTypeEs = "6";
                break;
            case "3":
            case "43":
                warningTypeEs = "1";
                break;
            case "4":
                warningTypeEs = "2";
                break;
            case "5":
                warningTypeEs = "3";
                break;
            case "6":
                warningTypeEs = "4";
                break;
            case "7":
                warningTypeEs = "10";
                break;
            case "8":
                warningTypeEs = "13";
                break;
            case "9":
            case "30":
            case "36":
            case "48":
                warningTypeEs = "104";
                break;
            case "10":
            case "29":
            case "49":
                warningTypeEs = "105";
                break;
            case "11":
            case "12":
                warningTypeEs = "101";
                break;
            case "13":
                warningTypeEs = "102";
                break;
            case "14":
                warningTypeEs = "103";
                break;
            case "15":
            case "44":
                warningTypeEs = "107";
                break;
            case "16":
                warningTypeEs = "108";
                break;
            case "21":
                warningTypeEs = "88";
                break;
            case "27":
            case "33":
                warningTypeEs = "188";
                break;
            case "17":
            case "18":
            case "19":
            case "20":
            case "23":
            case "24":
            case "45":
                warningTypeEs = "15";
                break;
            case "25":
                warningTypeEs = "89";
                break;
            case "26":
                warningTypeEs = "90";
                break;
            case "31":
            case "37":
                warningTypeEs = "189";
                break;
            case "32":
            case "38":
                warningTypeEs = "190";
                break;
            case "40":
            case "50":
                warningTypeEs = "106";
                break;
            case "41":
            case "42":
            case "47":
                warningTypeEs = "109";
                break;
            case "46":
                warningTypeEs = "108";
                break;
            case "51":
            case "52":
            case "53":
            case "54":
                warningTypeEs = "14";
                break;
            default:
                warningTypeEs = warningType;
                break;
        }
        return warningTypeEs;
    }

    /**
     * 转换预警类型【Linux】
     *
     * @param warningType
     * @return
     */
    private String convertTyTowerLinuxWarningType(String warningType) {
        String warningTypeEs;
        switch (warningType) {
            case "1":
                warningTypeEs = "1";
                break;
            case "2":
                warningTypeEs = "101";
                break;
            case "3":
                warningTypeEs = "4";
                break;
            case "4":
                warningTypeEs = "103";
                break;
            case "5":
                warningTypeEs = "3";
                break;
            case "6":
                warningTypeEs = "102";
                break;
            case "7":
                warningTypeEs = "7";
                break;
            case "8":
                warningTypeEs = "106";
                break;
            case "9":
                warningTypeEs = "10";
                break;
            case "10":
                warningTypeEs = "107";
                break;
            case "11":
                warningTypeEs = "13";
                break;
            case "12":
                warningTypeEs = "108";
                break;
            case "13":
                warningTypeEs = "5";
                break;
            case "14":
                warningTypeEs = "104";
                break;
            case "15":
                warningTypeEs = "6";
                break;
            case "16":
                warningTypeEs = "105";
                break;
            case "17":
                warningTypeEs = "14";
                break;
            case "18":
                warningTypeEs = "109";
                break;
            default:
                warningTypeEs = "0";
                break;
        }
        return warningTypeEs;
    }
}
