package com.yanzhu.jh.device.controller;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONArray;
import com.alibaba.fastjson2.JSONObject;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.constant.ApiConstants;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.enums.ShiFouEnum;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.common.utils.http.HttpUtils;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.yanzhu.jh.device.domain.DevIotConfig;
import com.yanzhu.jh.device.domain.DevIotConfigPoint;
import com.yanzhu.jh.device.service.IDevIotConfigPointService;
import com.yanzhu.jh.device.service.IDevIotConfigService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * 配电箱配置Controller
 * 
 * @author yanzhu
 * @date 2025-04-04
 */
@RestController
@RequestMapping("/device/iotConfig")
public class DevIotConfigController extends BaseController
{
    @Autowired
    private IDevIotConfigService devIotConfigService;

    @Autowired
    private IDevIotConfigPointService devIotConfigPointService;

    /**
     * 查询配电箱配置列表
     */
    @PreAuthorize("@ss.hasPermi('manage:iotConfig:list')")
    @GetMapping("/list")
    public TableDataInfo list(DevIotConfig devIotConfig)
    {
        startPage();
        List<DevIotConfig> list = devIotConfigService.selectDevIotConfigList(devIotConfig);
        return getDataTable(list);
    }

    /**
     * 导出配电箱配置列表
     */
    @PreAuthorize("@ss.hasPermi('manage:iotConfig:export')")
    @Log(title = "配电箱配置", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DevIotConfig devIotConfig)
    {
        List<DevIotConfig> list = devIotConfigService.selectDevIotConfigList(devIotConfig);
        ExcelUtil<DevIotConfig> util = new ExcelUtil<DevIotConfig>(DevIotConfig.class);
        util.exportExcel(response, list, "配电箱配置数据");
    }

    /**
     * 获取配电箱配置详细信息
     */
    @PreAuthorize("@ss.hasPermi('manage:iotConfig:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(devIotConfigService.selectDevIotConfigById(id));
    }

    /**
     * 新增配电箱配置
     */
            @PreAuthorize("@ss.hasPermi('manage:iotConfig:add')")
    @Log(title = "配电箱配置", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DevIotConfig devIotConfig)
    {
        int res = devIotConfigService.insertDevIotConfig(devIotConfig);
        if(res>0){
            return success(devIotConfig);
        }else{
            return error();
        }
    }

    /**
     * 修改配电箱配置
     */
            @PreAuthorize("@ss.hasPermi('manage:iotConfig:edit')")
    @Log(title = "配电箱配置", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DevIotConfig devIotConfig)
    {
        return toAjax(devIotConfigService.updateDevIotConfig(devIotConfig));
    }

    /**
     * 删除配电箱配置
     */
            @PreAuthorize("@ss.hasPermi('manage:iotConfig:remove')")
    @Log(title = "配电箱配置", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(devIotConfigService.deleteDevIotConfigByIds(ids));
    }

    /**
     * 获取配电箱配的点位信息
     * @return
     */
    @PreAuthorize("@ss.hasPermi('manage:iotConfig:query')")
    @GetMapping(value = "/findIotConfigPoint/{id}")
    public AjaxResult findIotConfigPoint(@PathVariable("id") Long id) {
        DevIotConfig devIotConfig = devIotConfigService.selectDevIotConfigById(id);
        String projectHashId = getSaDaProjectHashIds(devIotConfig.getSignalName(),devIotConfig.getSignalCode(), devIotConfig.getProjectName());
        if(StringUtils.isNotEmpty(projectHashId)){
            devIotConfig.setIsDel(ShiFouEnum.FOU.getCode());
            devIotConfigService.updateDevIotConfig(devIotConfig);
            // 根据项目主键，查询设备信息
            findSaDaBoxByProjectHashId(devIotConfig,projectHashId);
            return success();
        }else{
            return error();
        }
    }

    /**
     * 获取项目配置HashIds
     * @param signalName
     * @param signalCode
     * @param proName
     * @return
     */
    private static String getSaDaProjectHashIds(String signalName, String signalCode, String proName){
        try {
            Map<String, Object> params = new HashMap<>();
            params.put("username",signalName);
            params.put("password",signalCode);
            String resStr = HttpUtils.sendPost(ApiConstants.IOT_SD_HOST+"/v2/api-token-auth", JSON.toJSONString(params));
            JSONObject result = JSONObject.parseObject(resStr).getJSONObject("result");
            JSONObject accountJson = result.getJSONObject("account");
            if(StringUtils.isNotEmpty(accountJson.getString("canViewProjects"))){
                JSONArray canProjects = accountJson.getJSONArray("canViewProjects");
                if(canProjects.size()>0){
                    // 使用 forEach 和 Lambda 遍历
                    for(Object item:canProjects){
                        JSONObject obj = (JSONObject) item;
                        if(StringUtils.eqObj(obj.getString("name"),proName)){
                            return obj.getString("hashId");
                        }
                    }
                    return accountJson.getJSONObject("currentProject").getString("hashId");
                }else{
                    return accountJson.getJSONObject("currentProject").getString("hashId");
                }
            }else{
                return accountJson.getJSONObject("currentProject").getString("hashId");
            }
        }catch (Exception e){
            e.printStackTrace();
        }
        return null;
    }

    /**
     * 获取项目设备
     * @param devIotConfig
     * @param proHashId
     */
    private void findSaDaBoxByProjectHashId(DevIotConfig devIotConfig, String proHashId){
        try {
            String resStr = HttpUtils.sendGet(ApiConstants.IOT_SD_HOST+"/box/project/"+proHashId);
            JSONArray result = JSONObject.parseObject(resStr).getJSONArray("result");
            if(result.size()>0){
                DevIotConfigPoint pointQuery = new DevIotConfigPoint();
                pointQuery.setCfgId(devIotConfig.getId());
                List<DevIotConfigPoint> pointList = devIotConfigPointService.selectDevIotConfigPointList(pointQuery);
                result.forEach(item -> {
                    JSONObject obj = (JSONObject) item;
                    List<DevIotConfigPoint> pointItems = pointList.stream().filter(point -> StringUtils.eqObj(point.getDeviceSn(),obj.getString("hashId"))).collect(Collectors.toList());
                    if(pointItems.size()>0){
                        DevIotConfigPoint devIotConfigPoint = pointItems.get(0);
                        devIotConfigPoint.setDeviceName(obj.getString("name"));
                        devIotConfigPoint.setFactoryName(devIotConfig.getFactoryName());
                        devIotConfigPoint.setLevels(obj.getString("level"));
                        devIotConfigPoint.setLeakageCurrent(obj.getString("leakageCurrent"));
                        devIotConfigPoint.setRatedTemperature(obj.getString("ratedTemperature"));
                        devIotConfigPoint.setShortCircuitCurrent(obj.getString("shortCircuitCurrent"));
                        devIotConfigPoint.setRatedCurrent(obj.getString("ratedCurrent"));
                        devIotConfigPoint.setRatedVoltage(obj.getString("ratedVoltage"));
                        devIotConfigPoint.setOnlineStatus(obj.getJSONObject("device").getString("onlineStatus"));
                        devIotConfigPointService.updateDevIotConfigPoint(devIotConfigPoint);
                    }else{
                        DevIotConfigPoint devIotConfigPoint = new DevIotConfigPoint();
                        devIotConfigPoint.setCfgId(devIotConfig.getId());
                        devIotConfigPoint.setComId(devIotConfig.getComId());
                        devIotConfigPoint.setProjectId(devIotConfig.getProjectId());
                        devIotConfigPoint.setDeviceSn(obj.getString("hashId"));
                        devIotConfigPoint.setDeviceName(obj.getString("name"));
                        devIotConfigPoint.setFactoryName(devIotConfig.getFactoryName());
                        devIotConfigPoint.setLevels(obj.getString("level"));
                        devIotConfigPoint.setLeakageCurrent(obj.getString("leakageCurrent"));
                        devIotConfigPoint.setRatedTemperature(obj.getString("ratedTemperature"));
                        devIotConfigPoint.setShortCircuitCurrent(obj.getString("shortCircuitCurrent"));
                        devIotConfigPoint.setRatedCurrent(obj.getString("ratedCurrent"));
                        devIotConfigPoint.setRatedVoltage(obj.getString("ratedVoltage"));
                        devIotConfigPoint.setOnlineStatus(obj.getJSONObject("device").getString("onlineStatus"));
                        devIotConfigPointService.insertDevIotConfigPoint(devIotConfigPoint);
                    }
                });
            }
        }catch (Exception e){
            e.printStackTrace();
        }
    }
}
