package com.yanzhu.jh.device.controller;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.enums.ShiFouEnum;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.yanzhu.jh.device.domain.DevIotConfigPoint;
import com.yanzhu.jh.device.service.IDevIotConfigPointService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 配电箱配置Controller
 * 
 * @author yanzhu
 * @date 2025-04-04
 */
@RestController
@RequestMapping("/device/iotConfigPoint")
public class DevIotConfigPointController extends BaseController
{
    @Autowired
    private IDevIotConfigPointService devIotConfigPointService;

    /**
     * 查询配电箱配置列表
     */
    @PreAuthorize("@ss.hasPermi('manage:iotConfigPoint:list')")
    @GetMapping("/list")
    public TableDataInfo list(DevIotConfigPoint devIotConfigPoint)
    {
        startPage();
        List<DevIotConfigPoint> list = devIotConfigPointService.selectDevIotConfigPointList(devIotConfigPoint);
        return getDataTable(list);
    }

    /**
     * 导出配电箱配置列表
     */
    @PreAuthorize("@ss.hasPermi('manage:iotConfigPoint:export')")
    @Log(title = "配电箱配置", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DevIotConfigPoint devIotConfigPoint)
    {
        List<DevIotConfigPoint> list = devIotConfigPointService.selectDevIotConfigPointList(devIotConfigPoint);
        ExcelUtil<DevIotConfigPoint> util = new ExcelUtil<DevIotConfigPoint>(DevIotConfigPoint.class);
        util.exportExcel(response, list, "配电箱配置数据");
    }

    /**
     * 获取配电箱配置详细信息
     */
    @PreAuthorize("@ss.hasPermi('manage:iotConfigPoint:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(devIotConfigPointService.selectDevIotConfigPointById(id));
    }

    /**
     * 新增配电箱配置
     */
    @PreAuthorize("@ss.hasPermi('manage:iotConfigPoint:add')")
    @Log(title = "配电箱配置", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DevIotConfigPoint devIotConfigPoint)
    {
        return toAjax(devIotConfigPointService.insertDevIotConfigPoint(devIotConfigPoint));
    }

    /**
     * 修改配电箱配置
     */
    @PreAuthorize("@ss.hasPermi('manage:iotConfigPoint:edit')")
    @Log(title = "配电箱配置", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DevIotConfigPoint devIotConfigPoint)
    {
        return toAjax(devIotConfigPointService.updateDevIotConfigPoint(devIotConfigPoint));
    }

    /**
     * 删除配电箱配置
     */
    @PreAuthorize("@ss.hasPermi('manage:iotConfigPoint:remove')")
    @Log(title = "配电箱配置", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(devIotConfigPointService.deleteDevIotConfigPointByIds(ids));
    }

    /**
     * 查询配电箱配置列表
     */
    @GetMapping("/findProAllConfigPoint/{proId}")
    public AjaxResult findProAllConfigPoint(@PathVariable("proId") Long proId)
    {
        DevIotConfigPoint configPointQuery = new DevIotConfigPoint();
        configPointQuery.setProjectId(proId);
        configPointQuery.setIsDel(ShiFouEnum.FOU.getCode());
        List<DevIotConfigPoint> list = devIotConfigPointService.selectDevIotConfigPointList(configPointQuery);
        return success(list);
    }

}
