package com.yanzhu.jh.device.controller;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.yanzhu.jh.device.domain.DevIotDatas;
import com.yanzhu.jh.device.service.IDevIotDatasService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.time.LocalDate;
import java.util.*;

/**
 * 配电箱数据Controller
 * 
 * @author yanzhu
 * @date 2025-04-04
 */
@RestController
@RequestMapping("/device/iotDatas")
public class DevIotDatasController extends BaseController
{
    @Autowired
    private IDevIotDatasService devIotDatasService;

    /**
     * 查询配电箱数据列表
     */
    @PreAuthorize("@ss.hasPermi('manage:iotDatas:list')")
    @GetMapping("/list")
    public TableDataInfo list(DevIotDatas devIotDatas)
    {
        startPage();
        List<DevIotDatas> list = devIotDatasService.selectDevIotDatasList(devIotDatas);
        return getDataTable(list);
    }

    /**
     * 导出配电箱数据列表
     */
    @PreAuthorize("@ss.hasPermi('manage:iotDatas:export')")
    @Log(title = "配电箱数据", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DevIotDatas devIotDatas)
    {
        List<DevIotDatas> list = devIotDatasService.selectDevIotDatasList(devIotDatas);
        ExcelUtil<DevIotDatas> util = new ExcelUtil<DevIotDatas>(DevIotDatas.class);
        util.exportExcel(response, list, "配电箱数据数据");
    }

    /**
     * 获取配电箱数据详细信息
     */
    @PreAuthorize("@ss.hasPermi('manage:iotDatas:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(devIotDatasService.selectDevIotDatasById(id));
    }

    /**
     * 新增配电箱数据
     */
    @PreAuthorize("@ss.hasPermi('manage:iotDatas:add')")
    @Log(title = "配电箱数据", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DevIotDatas devIotDatas)
    {
        return toAjax(devIotDatasService.insertDevIotDatas(devIotDatas));
    }

    /**
     * 修改配电箱数据
     */
    @PreAuthorize("@ss.hasPermi('manage:iotDatas:edit')")
    @Log(title = "配电箱数据", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DevIotDatas devIotDatas)
    {
        return toAjax(devIotDatasService.updateDevIotDatas(devIotDatas));
    }

    /**
     * 删除配电箱数据
     */
    @PreAuthorize("@ss.hasPermi('manage:iotDatas:remove')")
    @Log(title = "配电箱数据", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(devIotDatasService.deleteDevIotDatasByIds(ids));
    }

    /**
     * 查询配电箱数据统计
     */
    @GetMapping("/findIotDatasMonitor/{proId}")
    public AjaxResult findProAllConfigPoint(@PathVariable("proId") Long proId, Long pointId, Integer date)
    {
        Calendar calendar = Calendar.getInstance();
        calendar.setTime(new Date());  // 设置为当前时间
        calendar.add(Calendar.DAY_OF_MONTH, Math.negateExact(date));  // 减去x天
        DevIotDatas datasQuery = new DevIotDatas();
        datasQuery.setPointId(pointId);
        datasQuery.setProjectId(proId);
        Map<String, Object> params = new HashMap<>();
        params.put("beginCreateTime", DateUtils.getNowDate());
        params.put("endCreateTime",calendar.getTime());
        List<DevIotDatas> list = devIotDatasService.selectDevIotDatasList(datasQuery);
        return success(list);
    }
}
