package com.yanzhu.jh.device.controller;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.yanzhu.jh.device.domain.DevIotWarning;
import com.yanzhu.jh.device.service.IDevIotWarningService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 配电箱预警Controller
 * 
 * @author yanzhu
 * @date 2025-04-04
 */
@RestController
@RequestMapping("/device/iotWarning")
public class DevIotWarningController extends BaseController
{
    @Autowired
    private IDevIotWarningService devIotWarningService;

    /**
     * 查询配电箱预警列表
     */
    @PreAuthorize("@ss.hasPermi('manage:iotWarning:list')")
    @GetMapping("/list")
    public TableDataInfo list(DevIotWarning devIotWarning)
    {
        startPage();
        List<DevIotWarning> list = devIotWarningService.selectDevIotWarningList(devIotWarning);
        return getDataTable(list);
    }

    /**
     * 导出配电箱预警列表
     */
    @PreAuthorize("@ss.hasPermi('manage:iotWarning:export')")
    @Log(title = "配电箱预警", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DevIotWarning devIotWarning)
    {
        List<DevIotWarning> list = devIotWarningService.selectDevIotWarningList(devIotWarning);
        ExcelUtil<DevIotWarning> util = new ExcelUtil<DevIotWarning>(DevIotWarning.class);
        util.exportExcel(response, list, "配电箱预警数据");
    }

    /**
     * 获取配电箱预警详细信息
     */
    @PreAuthorize("@ss.hasPermi('manage:iotWarning:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(devIotWarningService.selectDevIotWarningById(id));
    }

    /**
     * 新增配电箱预警
     */
    @PreAuthorize("@ss.hasPermi('manage:iotWarning:add')")
    @Log(title = "配电箱预警", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DevIotWarning devIotWarning)
    {
        return toAjax(devIotWarningService.insertDevIotWarning(devIotWarning));
    }

    /**
     * 修改配电箱预警
     */
    @PreAuthorize("@ss.hasPermi('manage:iotWarning:edit')")
    @Log(title = "配电箱预警", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DevIotWarning devIotWarning)
    {
        return toAjax(devIotWarningService.updateDevIotWarning(devIotWarning));
    }

    /**
     * 删除配电箱预警
     */
    @PreAuthorize("@ss.hasPermi('manage:iotWarning:remove')")
    @Log(title = "配电箱预警", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(devIotWarningService.deleteDevIotWarningByIds(ids));
    }

    /**
     * 查询配电箱预警数据
     */
    @GetMapping("/findIotWarnings/{proId}")
    public AjaxResult findIotWarnings(@PathVariable("proId") Long proId, Long pointId)
    {
        startPage(1,20);
        DevIotWarning warningQuery = new DevIotWarning();
        warningQuery.setPointId(pointId);
        warningQuery.setProjectId(proId);
        List<DevIotWarning> list = devIotWarningService.selectDevIotWarningList(warningQuery);
        return success(list);
    }
}
