package com.yanzhu.jh.device.service.impl;

import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.SecurityUtils;
import com.yanzhu.jh.device.domain.DevIotConfigPoint;
import com.yanzhu.jh.device.mapper.DevIotConfigPointMapper;
import com.yanzhu.jh.device.service.IDevIotConfigPointService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 配电箱配置Service业务层处理
 * 
 * @author yanzhu
 * @date 2025-04-04
 */
@Service
public class DevIotConfigPointServiceImpl implements IDevIotConfigPointService
{
    @Autowired
    private DevIotConfigPointMapper devIotConfigPointMapper;

    /**
     * 查询配电箱配置
     * 
     * @param id 配电箱配置主键
     * @return 配电箱配置
     */
    @Override
    public DevIotConfigPoint selectDevIotConfigPointById(Long id)
    {
        return devIotConfigPointMapper.selectDevIotConfigPointById(id);
    }

    /**
     * 查询配电箱配置列表
     * 
     * @param devIotConfigPoint 配电箱配置
     * @return 配电箱配置
     */
    @Override
    public List<DevIotConfigPoint> selectDevIotConfigPointList(DevIotConfigPoint devIotConfigPoint)
    {
        return devIotConfigPointMapper.selectDevIotConfigPointList(devIotConfigPoint);
    }

    /**
     * 新增配电箱配置
     * 
     * @param devIotConfigPoint 配电箱配置
     * @return 结果
     */
    @Override
    public int insertDevIotConfigPoint(DevIotConfigPoint devIotConfigPoint)
    {
        devIotConfigPoint.setCreateBy(SecurityUtils.getUsername());
        devIotConfigPoint.setCreateTime(DateUtils.getNowDate());
        return devIotConfigPointMapper.insertDevIotConfigPoint(devIotConfigPoint);
    }

    /**
     * 修改配电箱配置
     * 
     * @param devIotConfigPoint 配电箱配置
     * @return 结果
     */
    @Override
    public int updateDevIotConfigPoint(DevIotConfigPoint devIotConfigPoint)
    {
        devIotConfigPoint.setUpdateBy(SecurityUtils.getUsername());
        devIotConfigPoint.setUpdateTime(DateUtils.getNowDate());
        return devIotConfigPointMapper.updateDevIotConfigPoint(devIotConfigPoint);
    }

    /**
     * 批量删除配电箱配置
     * 
     * @param ids 需要删除的配电箱配置主键
     * @return 结果
     */
    @Override
    public int deleteDevIotConfigPointByIds(Long[] ids)
    {
        return devIotConfigPointMapper.deleteDevIotConfigPointByIds(ids);
    }

    /**
     * 删除配电箱配置信息
     * 
     * @param id 配电箱配置主键
     * @return 结果
     */
    @Override
    public int deleteDevIotConfigPointById(Long id)
    {
        return devIotConfigPointMapper.deleteDevIotConfigPointById(id);
    }
}
