package com.yanzhu.jh.device.service.impl;

import com.ruoyi.common.exception.ServiceException;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.common.utils.StringUtils;
import com.yanzhu.jh.device.domain.DevIotConfig;
import com.yanzhu.jh.device.mapper.DevIotConfigMapper;
import com.yanzhu.jh.device.service.IDevIotConfigService;
import com.yanzhu.jh.project.domain.SurProject;
import com.yanzhu.jh.project.mapper.SurProjectMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 配电箱配置Service业务层处理
 * 
 * @author yanzhu
 * @date 2025-04-04
 */
@Service
public class DevIotConfigServiceImpl implements IDevIotConfigService
{
    @Autowired
    private SurProjectMapper surProjectMapper;

    @Autowired
    private DevIotConfigMapper devIotConfigMapper;

    /**
     * 查询配电箱配置
     * 
     * @param id 配电箱配置主键
     * @return 配电箱配置
     */
    @Override
    public DevIotConfig selectDevIotConfigById(Long id)
    {
        return devIotConfigMapper.selectDevIotConfigById(id);
    }

    /**
     * 查询配电箱配置列表
     * 
     * @param devIotConfig 配电箱配置
     * @return 配电箱配置
     */
    @Override
    public List<DevIotConfig> selectDevIotConfigList(DevIotConfig devIotConfig)
    {
        return devIotConfigMapper.selectDevIotConfigList(devIotConfig);
    }

    /**
     * 新增配电箱配置
     * 
     * @param devIotConfig 配电箱配置
     * @return 结果
     */
    @Override
    public int insertDevIotConfig(DevIotConfig devIotConfig)
    {
        // 判断设备是否重复
        DevIotConfig configQuery = new DevIotConfig();
        configQuery.setProjectId(devIotConfig.getProjectId());
        configQuery.setSignalName(devIotConfig.getSignalName());
        configQuery.setSignalCode(devIotConfig.getSignalCode());
        List<DevIotConfig> list = devIotConfigMapper.selectDevIotConfigList(configQuery);
        if(list.size()>0){
            throw new ServiceException("配置信息重复添加！");
        }
        SurProject surProject = surProjectMapper.selectSurProjectById(devIotConfig.getProjectId());
        devIotConfig.setComId(surProject.getDeptId());
        devIotConfig.setIsDel("99");
        devIotConfig.setCreateBy(SecurityUtils.getUsername());
        devIotConfig.setCreateTime(DateUtils.getNowDate());
        return devIotConfigMapper.insertDevIotConfig(devIotConfig);
    }

    /**
     * 修改配电箱配置
     * 
     * @param devIotConfig 配电箱配置
     * @return 结果
     */
    @Override
    public int updateDevIotConfig(DevIotConfig devIotConfig)
    {
        // 判断设备是否重复
        if(StringUtils.isNotEmpty(devIotConfig.getSignalName()) && StringUtils.isNotEmpty(devIotConfig.getSignalCode())){
            DevIotConfig configQuery = new DevIotConfig();
            configQuery.setProjectId(devIotConfig.getProjectId());
            configQuery.setSignalName(devIotConfig.getSignalName());
            configQuery.setSignalCode(devIotConfig.getSignalCode());
            List<DevIotConfig> list = devIotConfigMapper.selectDevIotConfigList(configQuery);
            if(list.size()>0 && list.get(0).getId()!=devIotConfig.getId()){
                throw new ServiceException("配置信息重复添加！");
            }
        }
        devIotConfig.setUpdateBy(SecurityUtils.getUsername());
        devIotConfig.setUpdateTime(DateUtils.getNowDate());
        return devIotConfigMapper.updateDevIotConfig(devIotConfig);
    }

    /**
     * 批量删除配电箱配置
     * 
     * @param ids 需要删除的配电箱配置主键
     * @return 结果
     */
    @Override
    public int deleteDevIotConfigByIds(Long[] ids)
    {
        return devIotConfigMapper.deleteDevIotConfigByIds(ids);
    }

    /**
     * 删除配电箱配置信息
     * 
     * @param id 配电箱配置主键
     * @return 结果
     */
    @Override
    public int deleteDevIotConfigById(Long id)
    {
        return devIotConfigMapper.deleteDevIotConfigById(id);
    }
}
