package com.yanzhu.jh.device.service.impl;

import java.text.SimpleDateFormat;
import java.util.*;

import com.ruoyi.common.utils.DateUtils;
import com.yanzhu.jh.device.domain.DevTowerDataRound;
import com.yanzhu.jh.device.domain.DevTowerDataWarning;
import com.yanzhu.jh.device.mapper.DevTowerDataCollideMapper;
import com.yanzhu.jh.device.mapper.DevTowerDataRoundMapper;
import com.yanzhu.jh.device.mapper.DevTowerDataWarningMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.yanzhu.jh.device.mapper.DevTowerDataRunMapper;
import com.yanzhu.jh.device.domain.DevTowerDataRun;
import com.yanzhu.jh.device.service.IDevTowerDataRunService;

/**
 * 塔机实时数据Service业务层处理
 * 
 * @author JiangYuQi
 * @date 2024-08-04
 */
@Service
public class DevTowerDataRunServiceImpl implements IDevTowerDataRunService 
{
    @Autowired
    private DevTowerDataRunMapper devTowerDataRunMapper;

    @Autowired
    private DevTowerDataRoundMapper devTowerDataRoundMapper;

    @Autowired
    private DevTowerDataCollideMapper devTowerDataCollideMapper;

    @Autowired
    private DevTowerDataWarningMapper devTowerDataWarningMapper;

    /**
     * 查询塔机实时数据
     * 
     * @param id 塔机实时数据主键
     * @return 塔机实时数据
     */
    @Override
    public DevTowerDataRun selectDevTowerDataRunById(Long id)
    {
        return devTowerDataRunMapper.selectDevTowerDataRunById(id);
    }

    /**
     * 查询塔机实时数据列表
     * 
     * @param devTowerDataRun 塔机实时数据
     * @return 塔机实时数据
     */
    @Override
    public List<DevTowerDataRun> selectDevTowerDataRunList(DevTowerDataRun devTowerDataRun)
    {
        return devTowerDataRunMapper.selectDevTowerDataRunList(devTowerDataRun);
    }

    /**
     * 新增塔机实时数据
     * 
     * @param devTowerDataRun 塔机实时数据
     * @return 结果
     */
    @Override
    public int insertDevTowerDataRun(DevTowerDataRun devTowerDataRun)
    {
        //devTowerDataRun.setCreateBy(SecurityUtils.getUsername());
        devTowerDataRun.setCreateTime(DateUtils.getNowDate());
        return devTowerDataRunMapper.insertDevTowerDataRun(devTowerDataRun);
    }

    /**
     * 修改塔机实时数据
     * 
     * @param devTowerDataRun 塔机实时数据
     * @return 结果
     */
    @Override
    public int updateDevTowerDataRun(DevTowerDataRun devTowerDataRun)
    {
        //devTowerDataRun.setUpdateBy(SecurityUtils.getUsername());
        devTowerDataRun.setUpdateTime(DateUtils.getNowDate());
        return devTowerDataRunMapper.updateDevTowerDataRun(devTowerDataRun);
    }

    /**
     * 批量删除塔机实时数据
     * 
     * @param ids 需要删除的塔机实时数据主键
     * @return 结果
     */
    @Override
    public int deleteDevTowerDataRunByIds(Long[] ids)
    {
        return devTowerDataRunMapper.deleteDevTowerDataRunByIds(ids);
    }

    /**
     * 删除塔机实时数据信息
     * 
     * @param id 塔机实时数据主键
     * @return 结果
     */
    @Override
    public int deleteDevTowerDataRunById(Long id)
    {
        return devTowerDataRunMapper.deleteDevTowerDataRunById(id);
    }

    /**
     * 查询塔机运行数据
     * @return
     */
    @Override
    public Map<String, Object> findtowerStatisticsView(String deviceSn){
        Map<String, Object> dataMap = new HashMap<>();
        DevTowerDataRound devTowerDataRound = new DevTowerDataRound();
        devTowerDataRound.setDeviceKey(deviceSn);
        int a0 = devTowerDataRoundMapper.findRoundCountByDeviceKey(devTowerDataRound);
        dataMap.put("a0",a0);
        DevTowerDataWarning devTowerDataWarning = new DevTowerDataWarning();
        devTowerDataWarning.setDeviceKey(deviceSn);
        int b0 = devTowerDataWarningMapper.findOverloadWarningCountByDeviceKey(devTowerDataWarning);
        dataMap.put("b0",b0);
        int c0 = devTowerDataWarningMapper.findWarningCountByDeviceKey(devTowerDataWarning);
        dataMap.put("c0",c0);
        Calendar cale = Calendar.getInstance();
        // 获取当月第一天和最后一天
        SimpleDateFormat format = new SimpleDateFormat("yyyy-MM-dd");
        // 第一天
        String firstDay = "";
        cale = Calendar.getInstance();
        cale.add(Calendar.MONTH, 0);
        cale.set(Calendar.DAY_OF_MONTH, 1);
        firstDay = format.format(cale.getTime());
        // 最后一天
        String lastDay = "";
        cale = Calendar.getInstance();
        cale.add(Calendar.MONTH, 1);
        cale.set(Calendar.DAY_OF_MONTH, 0);
        lastDay = format.format(cale.getTime());
        Map<String, Object> params = new HashMap<>();
        params.put("beginCreateTime",firstDay);
        params.put("endCreateTime",lastDay);
        devTowerDataRound.setParams(params);
        devTowerDataWarning.setParams(params);
        int a1 = devTowerDataRoundMapper.findRoundCountByDeviceKey(devTowerDataRound);
        dataMap.put("a1",a1);
        int b1 = devTowerDataWarningMapper.findOverloadWarningCountByDeviceKey(devTowerDataWarning);
        dataMap.put("b1",b1);
        int c1 = devTowerDataWarningMapper.findWarningCountByDeviceKey(devTowerDataWarning);
        dataMap.put("c1",c1);
        return dataMap;
    }


}
