package com.yanzhu.jh.project.controller;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.stream.Collectors;
import javax.servlet.http.HttpServletResponse;

import cn.hutool.core.date.DateUtil;
import cn.hutool.core.util.StrUtil;
import com.ruoyi.common.utils.DateUtils;
import com.yanzhu.jh.project.domain.SurProjectAttendanceData;
import com.yanzhu.jh.project.domain.vo.ExportAttendancDay;
import com.yanzhu.jh.project.domain.vo.ExportAttendancMonth;
import com.yanzhu.jh.project.service.ISurProjectAttendanceDataService;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.yanzhu.jh.project.domain.SurProjectAttendanceUnitpay;
import com.yanzhu.jh.project.service.ISurProjectAttendanceUnitpayService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 劳资管理Controller
 * 
 * @author ruoyi
 * @date 2024-11-10
 */
@RestController
@RequestMapping("/project/unitpay")
public class SurProjectAttendanceUnitpayController extends BaseController
{
    @Autowired
    private ISurProjectAttendanceUnitpayService surProjectAttendanceUnitpayService;
    @Autowired
    private ISurProjectAttendanceDataService surProjectAttendanceDataService;
    /**
     * 查询劳资管理列表
     */
    @PreAuthorize("@ss.hasPermi('project:unitpay:list')")
    @GetMapping("/list")
    public AjaxResult list(SurProjectAttendanceUnitpay surProjectAttendanceUnitpay)
    {
        List<SurProjectAttendanceUnitpay> list = surProjectAttendanceUnitpayService.selectSurProjectAttendanceUnitpayList(surProjectAttendanceUnitpay);
        List<SurProjectAttendanceUnitpay>  iniList=surProjectAttendanceUnitpayService.initList(surProjectAttendanceUnitpay);
        for(SurProjectAttendanceUnitpay it :iniList){
            List<SurProjectAttendanceUnitpay> tmpList=  list.stream().filter(item->StrUtil.equals(it.getWorkTypeName(),item.getWorkTypeName()) && StrUtil.equals(it.getGroupName(),item.getGroupName())).collect(Collectors.toList());
           if(tmpList.isEmpty()){
               it.setUnitPay(0l);
               list.add(it);
           }
        }
        return success(list);
    }
    /**
     * 查询劳资管理列表
     */
    @PreAuthorize("@ss.hasPermi('project:unitpay:list')")
    @GetMapping("/listByDay")
    public TableDataInfo listByDay(SurProjectAttendanceData attWhere)
    {
        attWhere.setAttendanceOutTime(attWhere.getAttendanceOutTime());
        startPage();
        String tmp=attWhere.getAttendanceTime();
        if(StrUtil.isNotEmpty(tmp)){
            int year= DateUtil.parse(tmp).year();
            attWhere.setYear(year);
        }
        List<SurProjectAttendanceData> list = surProjectAttendanceDataService.selectSurProjectAttendanceDataListByDate(attWhere);
        if(list.size()==0){
            return getDataTable(list);
        }
        SurProjectAttendanceUnitpay payWhere=new SurProjectAttendanceUnitpay();
        payWhere.setCfgId(list.get(0).getCfgid());
        List<SurProjectAttendanceUnitpay> payList= surProjectAttendanceUnitpayService.selectSurProjectAttendanceUnitpayList(payWhere);
        for(SurProjectAttendanceData it :list){
            it.setDays(1l);
            it.setPay(surProjectAttendanceUnitpayService.getPay(payList,it));
        }

        return getDataTable(list);
    }

    /**
     * 查询两个日期之间某人的工资
     */
    @PreAuthorize("@ss.hasPermi('project:unitpay:list')")
    @GetMapping("/listByBetweenDay")
    public TableDataInfo listByBetweenDay(SurProjectAttendanceData attWhere)
    {
        attWhere.setAttendanceOutTime(attWhere.getAttendanceOutTime());
        startPage();
        String tmp=attWhere.getAttendanceTime();
        if(StrUtil.isNotEmpty(tmp)){
            int year= DateUtil.parse(tmp).year();
            attWhere.setYear(year);
        }
        List<SurProjectAttendanceData> list = surProjectAttendanceDataService.selectSurProjectAttendanceDataList(attWhere);
        if(list.size()==0){
            return getDataTable(list);
        }
        SurProjectAttendanceUnitpay payWhere=new SurProjectAttendanceUnitpay();
        payWhere.setCfgId(list.get(0).getCfgid());
        List<SurProjectAttendanceUnitpay> payList= surProjectAttendanceUnitpayService.selectSurProjectAttendanceUnitpayList(payWhere);
        for(SurProjectAttendanceData it :list){
            it.setDays(1l);
            it.setPay(surProjectAttendanceUnitpayService.getPay(payList,it));
        }

        return getDataTable(list);
    }

    /**
     *  按两个日期之间的时间差分组统计工资
     * @param attWhere
     * @return
     */
    @PreAuthorize("@ss.hasPermi('project:unitpay:list')")
    @GetMapping("/listGroupBetweenDay")
    public TableDataInfo listGroupBetweenDay(SurProjectAttendanceData attWhere)
    {
        startPage();
        String tmp=attWhere.getAttendanceTime();
        if(StrUtil.isNotEmpty(tmp)){
            int year= DateUtil.parse(tmp).year();
            attWhere.setYear(year);
        }
        List<SurProjectAttendanceData> list = surProjectAttendanceDataService.selectSurProjectAttendanceDataListByMonth(attWhere);
        if(list.size()==0){
            return getDataTable(list);
        }
        SurProjectAttendanceUnitpay payWhere=new SurProjectAttendanceUnitpay();
        payWhere.setCfgId(list.get(0).getCfgid());
        List<SurProjectAttendanceUnitpay> payList= surProjectAttendanceUnitpayService.selectSurProjectAttendanceUnitpayList(payWhere);
        for(SurProjectAttendanceData it :list){
            it.setPay(surProjectAttendanceUnitpayService.getPay(payList,it));
        }

        return getDataTable(list);
    }



    @PreAuthorize("@ss.hasPermi('project:unitpay:list')")
    @GetMapping("/listByMonth")
    public TableDataInfo listByMonth(SurProjectAttendanceData attWhere)
    {
        Date dt=DateUtil.parse(attWhere.getAttendanceTime());
        attWhere.setAttendanceTime( DateUtil.formatDate(DateUtil.beginOfMonth(dt)) );
        attWhere.setAttendanceOutTime( DateUtil.formatDate(DateUtil.endOfMonth(dt)));
        startPage();
        String tmp=attWhere.getAttendanceTime();
        if(StrUtil.isNotEmpty(tmp)){
            int year= DateUtil.parse(tmp).year();
            attWhere.setYear(year);
        }
        List<SurProjectAttendanceData> list = surProjectAttendanceDataService.selectSurProjectAttendanceDataListByMonth(attWhere);
        if(list.size()==0){
            return getDataTable(list);
        }
        SurProjectAttendanceUnitpay payWhere=new SurProjectAttendanceUnitpay();
        payWhere.setCfgId(list.get(0).getCfgid());
        List<SurProjectAttendanceUnitpay> payList= surProjectAttendanceUnitpayService.selectSurProjectAttendanceUnitpayList(payWhere);
        for(SurProjectAttendanceData it :list){
            it.setPay(surProjectAttendanceUnitpayService.getPay(payList,it));
        }

        return getDataTable(list);
    }

    /**
     * 按日导出工资
     */
    @PreAuthorize("@ss.hasPermi('project:unitpay:export')")
    @Log(title = "劳资管理", businessType = BusinessType.EXPORT)
    @PostMapping("/exportDay")
    public void exportDay(HttpServletResponse response, SurProjectAttendanceData attWhere)
    {
        Date dt=DateUtil.parse(attWhere.getAttendanceTime());
        attWhere.setAttendanceOutTime(attWhere.getAttendanceTime());
        String tmp=attWhere.getAttendanceTime();
        if(StrUtil.isNotEmpty(tmp)){
            int year= DateUtil.parse(tmp).year();
            attWhere.setYear(year);
        }
        List<SurProjectAttendanceData> list = surProjectAttendanceDataService.selectSurProjectAttendanceDataListByDate(attWhere);
        SurProjectAttendanceUnitpay payWhere=new SurProjectAttendanceUnitpay();
        if(list.size()>0){
            payWhere.setCfgId(list.get(0).getCfgid());
        }else {
            payWhere.setCfgId(attWhere.getCfgid());
        }
        List<SurProjectAttendanceUnitpay> payList= surProjectAttendanceUnitpayService.selectSurProjectAttendanceUnitpayList(payWhere);
        List<ExportAttendancDay> exportList=new ArrayList<ExportAttendancDay>();
        for(SurProjectAttendanceData it :list){
            it.setDays(1l);
            it.setPay(surProjectAttendanceUnitpayService.getPay(payList,it));
            exportList.add(ExportAttendancDay.NEW(it));
        }

        ExcelUtil<ExportAttendancDay> util = new ExcelUtil<ExportAttendancDay>(ExportAttendancDay.class);
        util.exportExcel(response, exportList, "劳务工资-日工资"+DateUtil.format(dt,"YYYY年MM月DD月"));
    }

    /**
     * 按月导出工资
     */
    @PreAuthorize("@ss.hasPermi('project:unitpay:export')")
    @Log(title = "劳资管理", businessType = BusinessType.EXPORT)
    @PostMapping("/exportMonth")
    public void exportMonth(HttpServletResponse response, SurProjectAttendanceData attWhere)
    {
        Date dt=DateUtil.parse(attWhere.getAttendanceTime());
        attWhere.setAttendanceTime( DateUtil.formatDate(DateUtil.beginOfMonth(dt)) );
        attWhere.setAttendanceOutTime( DateUtil.formatDate(DateUtil.endOfMonth(dt)));
        String tmp=attWhere.getAttendanceTime();
        if(StrUtil.isNotEmpty(tmp)){
            int year= DateUtil.parse(tmp).year();
            attWhere.setYear(year);
        }
        List<SurProjectAttendanceData> list = surProjectAttendanceDataService.selectSurProjectAttendanceDataListByMonth(attWhere);
        SurProjectAttendanceUnitpay payWhere=new SurProjectAttendanceUnitpay();
        if(list.size()>0){
            payWhere.setCfgId(list.get(0).getCfgid());
        }else {
            payWhere.setCfgId(attWhere.getCfgid());
        }
        List<SurProjectAttendanceUnitpay> payList= surProjectAttendanceUnitpayService.selectSurProjectAttendanceUnitpayList(payWhere);
        List<ExportAttendancMonth> exportList=new ArrayList<>();
        for(SurProjectAttendanceData it :list){
            it.setPay(surProjectAttendanceUnitpayService.getPay(payList,it));
            exportList.add(ExportAttendancMonth.NEW(it));
        }
        ExcelUtil<ExportAttendancMonth> util = new ExcelUtil<ExportAttendancMonth>(ExportAttendancMonth.class);
        util.exportExcel(response, exportList, "劳务工资-月工资"+DateUtil.format(dt,"YYYY年MM月"));
    }

    /**
     * 导出两个日期之间的每个员工统计考勤
     */
    @PreAuthorize("@ss.hasPermi('project:unitpay:export')")
    @Log(title = "劳资管理", businessType = BusinessType.EXPORT)
    @PostMapping("/exportGroupBetweenDay")
    public void exportGroupBetweenDay(HttpServletResponse response, SurProjectAttendanceData attWhere)
    {
        String tmp=attWhere.getAttendanceTime();
        if(StrUtil.isNotEmpty(tmp)){
            int year= DateUtil.parse(tmp).year();
            attWhere.setYear(year);
        }
        List<SurProjectAttendanceData> list = surProjectAttendanceDataService.selectSurProjectAttendanceDataListByMonth(attWhere);
        SurProjectAttendanceUnitpay payWhere=new SurProjectAttendanceUnitpay();
        if(list.size()>0){
            payWhere.setCfgId(list.get(0).getCfgid());
        }else {
            payWhere.setCfgId(attWhere.getCfgid());
        }
        List<SurProjectAttendanceUnitpay> payList= surProjectAttendanceUnitpayService.selectSurProjectAttendanceUnitpayList(payWhere);
        List<ExportAttendancMonth> exportList=new ArrayList<>();
        for(SurProjectAttendanceData it :list){
            it.setPay(surProjectAttendanceUnitpayService.getPay(payList,it));
            exportList.add(ExportAttendancMonth.NEW(it));
        }
        ExcelUtil<ExportAttendancMonth> util = new ExcelUtil<ExportAttendancMonth>(ExportAttendancMonth.class);
        util.exportExcel(response, exportList, "劳务工资-工资");
    }
    /**
     * 导出两个日期之间的某人工资
     */
    @PreAuthorize("@ss.hasPermi('project:unitpay:export')")
    @Log(title = "劳资管理", businessType = BusinessType.EXPORT)
    @PostMapping("/exportBetweenDay")
    public void exportBetWeenDay(HttpServletResponse response, SurProjectAttendanceData attWhere)
    {
        Date dt=DateUtil.parse(attWhere.getAttendanceTime());

        String tmp=attWhere.getAttendanceTime();
        if(StrUtil.isNotEmpty(tmp)){
            int year= DateUtil.parse(tmp).year();
            attWhere.setYear(year);
        }
        List<SurProjectAttendanceData> list = surProjectAttendanceDataService.selectSurProjectAttendanceDataList(attWhere);
        SurProjectAttendanceUnitpay payWhere=new SurProjectAttendanceUnitpay();
        if(list.size()>0){
            payWhere.setCfgId(list.get(0).getCfgid());
        }else {
            payWhere.setCfgId(attWhere.getCfgid());
        }
        List<SurProjectAttendanceUnitpay> payList= surProjectAttendanceUnitpayService.selectSurProjectAttendanceUnitpayList(payWhere);
        List<ExportAttendancDay> exportList=new ArrayList<ExportAttendancDay>();
        for(SurProjectAttendanceData it :list){
            it.setDays(1l);
            it.setPay(surProjectAttendanceUnitpayService.getPay(payList,it));
            exportList.add(ExportAttendancDay.NEW(it));
        }

        ExcelUtil<ExportAttendancDay> util = new ExcelUtil<ExportAttendancDay>(ExportAttendancDay.class);
        util.exportExcel(response, exportList, "劳务工资-工资");
    }
    /**
     * 获取劳资管理详细信息
     */
    @PreAuthorize("@ss.hasPermi('project:unitpay:query')")
    @GetMapping(value = "/one/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(surProjectAttendanceUnitpayService.selectSurProjectAttendanceUnitpayById(id));
    }

    /**
     * 新增劳资管理
     */
    @PreAuthorize("@ss.hasPermi('project:unitpay:add')")
    @Log(title = "劳资管理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody List<SurProjectAttendanceUnitpay> datas)
    {
        return toAjax(surProjectAttendanceUnitpayService.addSurProjectAttendanceUnitpaies(datas));
    }

    /**
     * 修改劳资管理
     */
    @PreAuthorize("@ss.hasPermi('project:unitpay:edit')")
    @Log(title = "劳资管理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody SurProjectAttendanceUnitpay surProjectAttendanceUnitpay)
    {
        return toAjax(surProjectAttendanceUnitpayService.updateSurProjectAttendanceUnitpay(surProjectAttendanceUnitpay));
    }

    /**
     * 删除劳资管理
     */
    @PreAuthorize("@ss.hasPermi('project:unitpay:remove')")
    @Log(title = "劳资管理", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(surProjectAttendanceUnitpayService.deleteSurProjectAttendanceUnitpayByIds(ids));
    }
}
